#example of usage of MySQLdb and _mysql
import MySQLdb
import _mysql
import classes
import sys

if not sys.modules.has_key('gtk'):
    import pygtk
    pygtk.require('1.2')

import gtk

thedb="test"
thetable="visit"
thehost="localhost"
theuser="root"
thepasswd=""


#connect
db = MySQLdb.connect(host=thehost, user=theuser,
                     passwd=thepasswd)

for t in ["person", "visit","lecture","event","classroom","course"]:
    w = classes.editor(db,thedb,t)
    w.connect("delete_event", gtk.mainquit)


gtk.mainloop()

del db




